@@ -1,9 +1,11 @@
+import ssl
 import time
-from typing import Any, Callable, List, Pattern, Tuple
+from typing import Any, Callable, Dict, List, Pattern, Tuple
 
 import requests.adapters
+# noinspection PyPackageRequirements
 import urllib3
-from requests import Session
+from requests import PreparedRequest, Request, Session
 
 from streamlink.exceptions import PluginError
 from streamlink.packages.requests_file import FileAdapter
@@ -14,14 +16,6 @@ from streamlink.utils.parse import parse_json, parse_xml
 urllib3_version = tuple(map(int, urllib3.__version__.split(".")[:3]))
 
 
-try:
-    # We tell urllib3 to disable warnings about unverified HTTPS requests,
-    # because in some plugins we have to do unverified requests intentionally.
-    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
-except AttributeError:
-    pass
-
-
 class _HTTPResponse(urllib3.response.HTTPResponse):
     def __init__(self, *args, **kwargs):
         # Always enforce content length validation!
@@ -44,8 +38,8 @@ class _HTTPResponse(urllib3.response.HTTPResponse):
 
 
 # override all urllib3.response.HTTPResponse references in requests.adapters.HTTPAdapter.send
-urllib3.connectionpool.HTTPConnectionPool.ResponseCls = _HTTPResponse
-requests.adapters.HTTPResponse = _HTTPResponse
+urllib3.connectionpool.HTTPConnectionPool.ResponseCls = _HTTPResponse  # type: ignore[attr-defined]
+requests.adapters.HTTPResponse = _HTTPResponse  # type: ignore[misc]
 
 
 # Never convert percent-encoded characters to uppercase in urllib3>=1.25.4.
@@ -61,7 +55,7 @@ requests.adapters.HTTPResponse = _HTTPResponse
 # > encodings.
 if urllib3_version >= (1, 25, 4):
     class Urllib3UtilUrlPercentReOverride:
-        _re_percent_encoding: Pattern = urllib3.util.url.PERCENT_RE
+        _re_percent_encoding: Pattern = urllib3.util.url.PERCENT_RE  # type: ignore[attr-defined]
 
         @classmethod
         def _num_percent_encodings(cls, string) -> int:
@@ -83,7 +77,7 @@ if urllib3_version >= (1, 25, 4):
 
             return _List()
 
-    urllib3.util.url.PERCENT_RE = Urllib3UtilUrlPercentReOverride
+    urllib3.util.url.PERCENT_RE = Urllib3UtilUrlPercentReOverride  # type: ignore[attr-defined]
 
 
 def _parse_keyvalue_list(val):
@@ -95,7 +89,13 @@ def _parse_keyvalue_list(val):
             continue
 
 
+# requests.Request.__init__ keywords, except for "hooks"
+_VALID_REQUEST_ARGS = "method", "url", "headers", "files", "data", "params", "auth", "cookies", "json"
+
+
 class HTTPSession(Session):
+    params: Dict
+
     def __init__(self):
         super().__init__()
 
@@ -167,6 +167,18 @@ class HTTPSession(Session):
         """Resolves any redirects and returns the final URL."""
         return self.get(url, stream=True).url
 
+    @staticmethod
+    def valid_request_args(**req_keywords) -> Dict:
+        return {k: v for k, v in req_keywords.items() if k in _VALID_REQUEST_ARGS}
+
+    def prepare_new_request(self, **req_keywords) -> PreparedRequest:
+        valid_args = self.valid_request_args(**req_keywords)
+        valid_args.setdefault("method", "GET")
+        request = Request(**valid_args)
+
+        # prepare request with the session context, which might add params, headers, cookies, etc.
+        return self.prepare_request(request)
+
     def request(self, method, url, *args, **kwargs):
         acceptable_status = kwargs.pop("acceptable_status", [])
         exception = kwargs.pop("exception", PluginError)
@@ -220,4 +232,12 @@ class HTTPSession(Session):
         return res
 
 
-__all__ = ["HTTPSession"]
+class TLSSecLevel1Adapter(requests.adapters.HTTPAdapter):
+    def init_poolmanager(self, *args, **kwargs):
+        ctx = ssl.create_default_context()
+        ctx.set_ciphers("DEFAULT:@SECLEVEL=1")
+        kwargs["ssl_context"] = ctx
+        return super().init_poolmanager(*args, **kwargs)
+
+
+__all__ = ["HTTPSession", "TLSSecLevel1Adapter"]
