@@ -1,4 +1,5 @@
 """
+$description TV network with multiple live TV channels broadcasting across various Latin American countries.
 $url antena7.com.do
 $url atv.pe
 $url c9n.com.py
@@ -84,53 +85,47 @@ class Albavision(Plugin):
         schema = validate.Schema(
             validate.xml_xpath_string(".//script[contains(text(), 'jQuery.get')]/text()"),
         )
-        is_token_based_site = validate.validate(schema, self.page) is not None
+        is_token_based_site = schema.validate(self.page) is not None
         log.debug(f"is_token_based_site={is_token_based_site}")
         return is_token_based_site
 
     def _get_live_url(self):
-        live_url_re = re.compile(r"""LIVE_URL\s*=\s*['"]([^'"]+)['"]""")
         schema = validate.Schema(
             validate.xml_xpath_string(".//script[contains(text(), 'LIVE_URL')]/text()"),
-            validate.any(None, validate.all(
-                validate.transform(live_url_re.search),
-                validate.any(None, validate.all(
+            validate.none_or_all(
+                re.compile(r"""LIVE_URL\s*=\s*(?P<q>['"])(.+?)(?P=q)"""),
+                validate.none_or_all(
                     validate.get(1),
                     validate.url(),
-                )),
-            )),
+                ),
+            ),
         )
-        live_url = validate.validate(schema, self.page)
+        live_url = schema.validate(self.page)
         log.debug(f"live_url={live_url}")
         return live_url
 
     def _get_token_req_url(self):
-        token_req_host_re = re.compile(r"""jQuery\.get\s*\(['"]([^'"]+)['"]""")
         schema = validate.Schema(
             validate.xml_xpath_string(".//script[contains(text(), 'LIVE_URL')]/text()"),
-            validate.any(None, validate.all(
-                validate.transform(token_req_host_re.search),
-                validate.any(None, validate.all(
+            validate.none_or_all(
+                re.compile(r"""jQuery\.get\s*\((?P<q>['"])(.+?)(?P=q)"""),
+                validate.none_or_all(
                     validate.get(1),
                     validate.url(),
-                )),
-            )),
+                ),
+            ),
         )
-        token_req_host = validate.validate(schema, self.page)
+        token_req_host = schema.validate(self.page)
         log.debug(f"token_req_host={token_req_host}")
 
-        token_req_str_re = re.compile(r"""Math\.floor\(Date\.now\(\)\s*/\s*3600000\),\s*['"]([^'"]+)['"]""")
         schema = validate.Schema(
             validate.xml_xpath_string(".//script[contains(text(), 'LIVE_URL')]/text()"),
-            validate.any(None, validate.all(
-                validate.transform(token_req_str_re.search),
-                validate.any(None, validate.all(
-                    validate.get(1),
-                    str,
-                )),
-            )),
+            validate.none_or_all(
+                re.compile(r"""Math\.floor\(Date\.now\(\)\s*/\s*3600000\),\s*(?P<q>['"])(.+?)(?P=q)"""),
+                validate.none_or_all(validate.get(1)),
+            ),
         )
-        token_req_str = validate.validate(schema, self.page)
+        token_req_str = schema.validate(self.page)
         log.debug(f"token_req_str={token_req_str}")
         if not token_req_str:
             return
