@@ -3,6 +3,7 @@ import numbers
 import re
 from string import printable
 from textwrap import dedent
+from typing import Dict, List, Optional
 
 from streamlink import __version__ as streamlink_version, logger
 from streamlink.utils.args import (
@@ -26,6 +27,27 @@ _option_re = re.compile(r"""
 
 
 class ArgumentParser(argparse.ArgumentParser):
+    # noinspection PyUnresolvedReferences,PyProtectedMember
+    NESTED_ARGUMENT_GROUPS: Dict[Optional[argparse._ArgumentGroup], List[argparse._ArgumentGroup]]
+
+    def __init__(self, *args, **kwargs):
+        self.NESTED_ARGUMENT_GROUPS = {}
+        super().__init__(*args, **kwargs)
+
+    # noinspection PyUnresolvedReferences,PyProtectedMember
+    def add_argument_group(
+        self,
+        *args,
+        parent: Optional[argparse._ArgumentGroup] = None,
+        **kwargs
+    ) -> argparse._ArgumentGroup:
+        group = super().add_argument_group(*args, **kwargs)
+        if parent not in self.NESTED_ARGUMENT_GROUPS:
+            self.NESTED_ARGUMENT_GROUPS[parent] = [group]
+        else:
+            self.NESTED_ARGUMENT_GROUPS[parent].append(group)
+        return group
+
     def convert_arg_line_to_args(self, line):
         # Strip any non-printable characters that might be in the
         # beginning of the line (e.g. Unicode BOM marker).
@@ -87,16 +109,18 @@ class ArgumentParser(argparse.ArgumentParser):
         # description
         formatter.add_text(self.description)
 
-        def format_group(group):
+        def format_group(parent):
+            if parent not in self.NESTED_ARGUMENT_GROUPS:
+                return
             # positionals, optionals and user-defined groups
-            for action_group in group._action_groups:
+            for action_group in self.NESTED_ARGUMENT_GROUPS[parent]:
                 formatter.start_section(action_group.title)
                 formatter.add_text(action_group.description)
                 formatter.add_arguments(action_group._group_actions)
                 format_group(action_group)
                 formatter.end_section()
 
-        format_group(self)
+        format_group(None)
 
         # epilog
         formatter.add_text(self.epilog)
@@ -118,11 +142,10 @@ class HelpFormatter(argparse.RawDescriptionHelpFormatter):
     def __init__(self, max_help_position=4, *args, **kwargs):
         # A smaller indent for args help.
         kwargs["max_help_position"] = max_help_position
-        argparse.RawDescriptionHelpFormatter.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def _split_lines(self, text, width):
-        text = dedent(text).strip() + "\n\n"
-        return text.splitlines()
+        return f"{dedent(text).strip()}\n\n".splitlines()
 
 
 def build_parser():
@@ -153,7 +176,7 @@ def build_parser():
         help="""
         A URL to attempt to extract streams from.
 
-        Usually, the protocol of http(s) URLs can be omitted ("https://"),
+        Usually, the protocol of http(s) URLs can be omitted (`https://`),
         depending on the implementation of the plugin being used.
 
         Alternatively, the URL can also be specified by using the --url option.
@@ -167,7 +190,7 @@ def build_parser():
         help="""
         Stream to play.
 
-        Use ``best`` or ``worst`` for selecting the highest or lowest available
+        Use `best` or `worst` for selecting the highest or lowest available
         quality.
 
         Fallback streams can be specified by using a comma-separated list:
@@ -218,7 +241,7 @@ def build_parser():
         help="""
         Check if Streamlink has a plugin that can handle the specified URL.
 
-        Returns status code 1 for false and 0 for true.
+        Returns status code `1` for false and `0` for true.
 
         Useful for external scripting.
         """
@@ -250,18 +273,18 @@ def build_parser():
         help="""
         Set the log message threshold.
 
-        Valid levels are: none, error, warning, info, debug, trace
+        Valid levels are: `none`, `error`, `warning`, `info`, `debug`, `trace`
         """
     )
     general.add_argument(
         "--logfile",
         metavar="FILE",
         help="""
-        Append log output to FILE instead of writing to stdout/stderr.
+        Append log output to `FILE` instead of writing to stdout/stderr.
 
-        User prompts and download progress won't be written to FILE.
+        User prompts and download progress won't be written to `FILE`.
 
-        A value of ``-`` will set the file name to an ISO8601-like string
+        A value of `-` (dash) will set the file name to an ISO8601-like string
         and will choose the following default log directories.
 
         Windows:
@@ -283,7 +306,7 @@ def build_parser():
         help="""
         Hide all log output.
 
-        Alias for "--loglevel none".
+        Alias for `--loglevel none`.
         """
     )
     general.add_argument(
@@ -321,8 +344,8 @@ def build_parser():
         The preferred locale setting, for selecting the preferred subtitle and
         audio language.
 
-        The locale is formatted as [language_code]_[country_code], eg. en_US or
-        es_ES.
+        The locale is formatted as `[language_code]_[country_code]`, eg. `en_US` or
+        `es_ES`.
 
         Default is system locale.
         """
@@ -339,14 +362,14 @@ def build_parser():
         "-4", "--ipv4",
         action="store_true",
         help="""
-        Resolve address names to IPv4 only. This option overrides :option:`-6`.
+        Resolve address names to IPv4 only. This option overrides --ipv6.
         """
     )
     general.add_argument(
         "-6", "--ipv6",
         action="store_true",
         help="""
-        Resolve address names to IPv6 only. This option overrides :option:`-4`.
+        Resolve address names to IPv6 only. This option overrides --ipv4.
         """
     )
 
@@ -396,14 +419,14 @@ def build_parser():
         any of the player arguments to be logged.
 
         The value can contain formatting variables surrounded by curly braces,
-        {{ and }}. If you need to include a brace character, it can be escaped
-        by doubling, e.g. {{{{ and }}}}.
+        `{{` and `}}`. If you need to include a brace character, it can be escaped
+        by doubling, e.g. `{{{{` and `}}}}`.
 
         Formatting variables available:
 
         {{{PLAYER_ARGS_INPUT_DEFAULT}}}
             This is the input that the player will use. For standard input (stdin),
-            it is ``-``, but it can also be a URL, depending on the options used.
+            it is `-` (dash), but it can also be a URL, depending on the options used.
 
         {{{PLAYER_ARGS_INPUT_FALLBACK}}}
             The old fallback variable name with the same functionality.
@@ -412,7 +435,7 @@ def build_parser():
 
           %(prog)s -p vlc -a "--play-and-exit {{{PLAYER_ARGS_INPUT_DEFAULT}}}" <url> [stream]
 
-        Note: When neither of the variables are found, ``{{{PLAYER_ARGS_INPUT_DEFAULT}}}``
+        Note: When neither of the variables are found, `{{{PLAYER_ARGS_INPUT_DEFAULT}}}`
         will be appended to the whole parameter value, to ensure that the player
         always receives an input argument.
         """
@@ -474,7 +497,7 @@ def build_parser():
         default=0,
         help="""
         A fixed port to use for the external HTTP server if that mode is
-        enabled. Omit or set to 0 to use a random high ( >1024) port.
+        enabled. Omit or set to `0` to use a random high ( >1024) port.
         """
     )
     player.add_argument(
@@ -525,7 +548,7 @@ def build_parser():
             in front of the dollar sign which VLC uses as its formatting character.
 
             For example, to put the current date in your VLC window title,
-            the string "\\\\$A" could be inserted inside the --title string.
+            the string `\\$A` could be inserted inside the --title string.
 
         Example:
 
@@ -538,7 +561,7 @@ def build_parser():
         "-o", "--output",
         metavar="FILENAME",
         help="""
-        Write stream data to FILENAME instead of playing it. If FILENAME is set to - (dash), then the stream data will be
+        Write stream data to `FILENAME` instead of playing it. If `FILENAME` is set to `-` (dash), then the stream data will be
         written to stdout, similar to the --stdout argument.
 
         Non-existent directories and subdirectories will be created if they do not exist, if filesystem permissions allow.
@@ -580,8 +603,8 @@ def build_parser():
         "-r", "--record",
         metavar="FILENAME",
         help="""
-        Open the stream in the player, while at the same time writing it to FILENAME. If FILENAME is set to - (dash), then the
-        stream data will be written to stdout, similar to the --stdout argument, while still opening the player.
+        Open the stream in the player, while at the same time writing it to `FILENAME`. If `FILENAME` is set to `-` (dash),
+        then the stream data will be written to stdout, similar to the --stdout argument, while still opening the player.
 
         Non-existent directories and subdirectories will be created if they do not exist, if filesystem permissions allow.
 
@@ -600,7 +623,7 @@ def build_parser():
         "-R", "--record-and-pipe",
         metavar="FILENAME",
         help="""
-        Write stream data to stdout, while at the same time writing it to FILENAME.
+        Write stream data to stdout, while at the same time writing it to `FILENAME`.
 
         Non-existent directories and subdirectories will be created if they do not exist, if filesystem permissions allow.
 
@@ -630,8 +653,8 @@ def build_parser():
 
         These characters are replaced with an underscore for the rules in use:
 
-          POSIX  : \\x00-\\x1F /
-          Windows: \\x00-\\x1F \\x7F " * / : < > ? \\ |
+        - POSIX: `\\x00-\\x1F /`
+        - Windows: `\\x00-\\x1F \\x7F " * / : < > ? \\ |`
         """
     )
 
@@ -643,7 +666,7 @@ def build_parser():
         help="""
         A URL to attempt to extract streams from.
 
-        Usually, the protocol of http(s) URLs can be omitted (https://),
+        Usually, the protocol of http(s) URLs can be omitted (`https://`),
         depending on the implementation of the plugin being used.
 
         This is an alternative to setting the URL using a positional argument
@@ -657,7 +680,7 @@ def build_parser():
         help="""
         Stream to play.
 
-        Use ``best`` or ``worst`` for selecting the highest or lowest available
+        Use `best` or `worst` for selecting the highest or lowest available
         quality.
 
         Fallback streams can be specified by using a comma-separated list:
@@ -681,7 +704,7 @@ def build_parser():
         type=num(float, min=0),
         help="""
         Retry fetching the list of available streams until streams are found
-        while waiting DELAY second(s) between each attempt. If unset, only one
+        while waiting `DELAY` second(s) between each attempt. If unset, only one
         attempt will be made to fetch the list of streams available.
 
         The number of fetch retry attempts can be capped with --retry-max.
@@ -692,8 +715,8 @@ def build_parser():
         metavar="COUNT",
         type=num(int, min=-1),
         help="""
-        When using --retry-streams, stop retrying the fetch after COUNT retry
-        attempt(s). Fetch will retry infinitely if COUNT is zero or unset.
+        When using --retry-streams, stop retrying the fetch after `COUNT` retry
+        attempt(s). Fetch will retry infinitely if `COUNT` is zero or unset.
 
         If --retry-max is set without setting --retry-streams, the delay between
         retries will default to 1 second.
@@ -705,7 +728,7 @@ def build_parser():
         type=num(int, min=0),
         default=1,
         help="""
-        After a successful fetch, try ATTEMPTS time(s) to open the stream until
+        After a successful fetch, try `ATTEMPTS` time(s) to open the stream until
         giving up.
 
         Default is 1.
@@ -720,7 +743,7 @@ def build_parser():
 
         The order will be used to separate streams when there are multiple
         streams with the same name but different stream types. Any stream type
-        not listed will be omitted from the available streams list.  A ``*`` can
+        not listed will be omitted from the available streams list.  An `*` (asterisk) can
         be used as a wildcard to match any other type of stream, eg. muxed-stream.
 
         Default is "hls,http,*".
@@ -731,35 +754,35 @@ def build_parser():
         metavar="STREAMS",
         type=comma_list,
         help="""
-        Fine tune the ``best`` and ``worst`` stream name synonyms by excluding unwanted streams.
+        Fine tune the `best` and `worst` stream name synonyms by excluding unwanted streams.
 
-        If all of the available streams get excluded, ``best`` and ``worst`` will become
-        inaccessible and new special stream synonyms ``best-unfiltered`` and ``worst-unfiltered``
+        If all of the available streams get excluded, `best` and `worst` will become
+        inaccessible and new special stream synonyms `best-unfiltered` and `worst-unfiltered`
         can be used as a fallback selection method.
 
         Uses a filter expression in the format:
 
           [operator]<value>
 
-        Valid operators are ``>``, ``>=``, ``<`` and ``<=``. If no operator is specified then
+        Valid operators are `>`, `>=`, `<` and `<=`. If no operator is specified then
         equality is tested.
 
         For example this will exclude streams ranked higher than "480p":
 
-          ">480p"
+          --stream-sorting-excludes ">480p"
 
         Multiple filters can be used by separating each expression with a comma.
 
         For example this will exclude streams from two quality types:
 
-          ">480p,>medium"
+          --stream-sorting-excludes ">480p,>medium"
 
         """
     )
 
     transport = parser.add_argument_group("Stream transport options")
-    transport_hls = transport.add_argument_group("HLS options")
-    transport_ffmpeg = transport.add_argument_group("FFmpeg options")
+    transport_hls = parser.add_argument_group("HLS options", parent=transport)
+    transport_ffmpeg = parser.add_argument_group("FFmpeg options", parent=transport)
 
     transport.add_argument(
         "--ringbuffer-size",
@@ -801,7 +824,7 @@ def build_parser():
         type=num(int, max=10),
         metavar="THREADS",
         help="""
-        The size of the thread pool used to download segments. Minimum value is 1 and maximum is 10.
+        The size of the thread pool used to download segments. Minimum value is `1` and maximum is `10`.
 
         This applies to all different kinds of segmented stream types, such as DASH, HLS, etc.
 
@@ -886,9 +909,9 @@ def build_parser():
         Set a custom HLS playlist reload time value, either in seconds
         or by using one of the following keywords:
 
-            segment: The duration of the last segment in the current playlist
-            live-edge: The sum of segment durations of the live edge value minus one
-            default: The playlist's target duration metadata
+        - segment: The duration of the last segment in the current playlist
+        - live-edge: The sum of segment durations of the live edge value minus one
+        - default: The playlist's target duration metadata
 
         Default is default.
         """
@@ -934,7 +957,7 @@ def build_parser():
         metavar="CODE",
         help="""
         Selects a specific audio source or sources, by language code or name,
-        when multiple audio sources are available. Can be * to download all
+        when multiple audio sources are available. Can be `*` (asterisk) to download all
         audio sources.
 
         Examples:
@@ -993,9 +1016,9 @@ def build_parser():
         help="""
         FFMPEG is used to access or mux separate video and audio streams. You
         can specify the location of the ffmpeg executable if it is not in your
-        PATH.
+        `PATH`.
 
-        Example: "/usr/local/bin/ffmpeg"
+        Example: --ffmpeg-ffmpeg "/usr/local/bin/ffmpeg"
         """
     )
     transport_ffmpeg.add_argument(
@@ -1018,40 +1041,40 @@ def build_parser():
         type=str,
         metavar="OUTFORMAT",
         help="""
-        When muxing streams, set the output format to OUTFORMAT.
+        When muxing streams, set the output format to `OUTFORMAT`.
 
         Default is "matroska".
 
-        Example: "mpegts"
+        Example: --ffmpeg-fout "mpegts"
         """
     )
     transport_ffmpeg.add_argument(
         "--ffmpeg-video-transcode",
         metavar="CODEC",
         help="""
-        When muxing streams, transcode the video to CODEC.
+        When muxing streams, transcode the video to `CODEC`.
 
         Default is "copy".
 
-        Example: "h264"
+        Example: --ffmpeg-video-transcode "h264"
         """
     )
     transport_ffmpeg.add_argument(
         "--ffmpeg-audio-transcode",
         metavar="CODEC",
         help="""
-        When muxing streams, transcode the audio to CODEC.
+        When muxing streams, transcode the audio to `CODEC`.
 
         Default is "copy".
 
-        Example: "aac"
+        Example: --ffmpeg-audio-transcode "aac"
         """
     )
     transport_ffmpeg.add_argument(
         "--ffmpeg-copyts",
         action="store_true",
         help="""
-        Forces the -copyts ffmpeg option and does not remove
+        Forces the `-copyts` ffmpeg option and does not remove
         the initial start time offset value.
         """
     )
@@ -1059,7 +1082,7 @@ def build_parser():
         "--ffmpeg-start-at-zero",
         action="store_true",
         help="""
-        Enable the -start_at_zero ffmpeg option when using copyts.
+        Enable the `-start_at_zero` ffmpeg option when using --ffmpeg-copyts.
         """
     )
 
@@ -1070,7 +1093,7 @@ def build_parser():
         help="""
         A HTTP proxy to use for all HTTP and HTTPS requests, including WebSocket connections.
 
-        Example: "http://hostname:port/"
+        Example: --http-proxy "http://hostname:port/"
         """
     )
     http.add_argument("--https-proxy", help=argparse.SUPPRESS)
@@ -1112,7 +1135,7 @@ def build_parser():
         action="store_true",
         help="""
         Ignore HTTP settings set in the environment such as environment
-        variables (HTTP_PROXY, etc) or ~/.netrc authentication.
+        variables (`HTTP_PROXY`, etc) or `~/.netrc` authentication.
         """
     )
     http.add_argument(
@@ -1167,4 +1190,4 @@ def build_parser():
     return parser
 
 
-__all__ = ["build_parser"]
+__all__ = ["ArgumentParser", "build_parser"]
