@@ -108,6 +108,7 @@ class TestPluginMetadata:
     @pytest.fixture(scope="class")
     def metadata_keys_required(self):
         return (
+            "description",
             "url",
             "type",
         )
@@ -189,19 +190,3 @@ class TestPluginMetadata:
     def test_key_type(self, metadata_dict):
         assert metadata_dict.get("type") in ("live", "vod", "live, vod"), \
             "Type metadata has the correct value"
-
-
-class TestRemovedPluginsFile:
-    @pytest.fixture(scope="class")
-    def removedplugins(self):
-        with (Path(plugins_path) / ".removed").open() as handle:
-            return [line.strip() for line in handle.readlines() if not line.strip().startswith("#")]
-
-    @pytest.mark.parametrize("plugin", plugins)
-    def test_plugin_not_in_file(self, plugin, removedplugins):
-        assert plugin not in removedplugins, "Existing plugin is not in removed plugins list"
-
-    def test_is_sorted(self, removedplugins):
-        removedplugins_sorted = removedplugins.copy()
-        removedplugins_sorted.sort()
-        assert removedplugins_sorted == removedplugins, "Removed plugins list is sorted alphabetically"
